@@ -77,6 +77,7 @@ custom_components = {'j-tooltip': 'components/tooltip.vue',
                      'j-plugin-section-header': 'components/plugin_section_header.vue',
                      'j-number-uncertainty': 'components/number_uncertainty.vue',
                      'j-plugin-popout': 'components/plugin_popout.vue',
+                     'plugin-table': 'components/plugin_table.vue',
                      'plugin-dataset-select': 'components/plugin_dataset_select.vue',
                      'plugin-subset-select': 'components/plugin_subset_select.vue',
                      'plugin-viewer-select': 'components/plugin_viewer_select.vue',
@@ -424,7 +425,11 @@ class Application(VuetifyTemplate, HubListener):
                      LinkSame(linked_data.components[0], ref_data.components[1])]
             dc.add_link(links)
             return
-        elif linked_data.meta.get('Plugin', None) == 'SpectralExtraction':
+        elif (linked_data.meta.get('Plugin', None) == 'SpectralExtraction' or
+                (linked_data.meta.get('Plugin', None) == ('GaussianSmooth') and
+                 linked_data.ndim < 3 and  # Cube linking requires special logic. See below
+                 ref_data.ndim < 3)
+              ):
             links = [LinkSame(linked_data.components[0], ref_data.components[0]),
                      LinkSame(linked_data.components[1], ref_data.components[1])]
             dc.add_link(links)
@@ -810,7 +815,7 @@ class Application(VuetifyTemplate, HubListener):
                     # TODO: this needs to be much simpler; i.e. data units in
                     #  the glue component objects
                     # Cases where there is a single subset
-                    if '_orig_wcs' in value.data.meta:  # Hack for Cubeviz WCS propagation
+                    if '_orig_spec' in value.data.meta:  # Hack for Cubeviz WCS propagation
                         data_wcs = value.data.meta['_orig_spec']
                     else:
                         data_wcs = value.data.coords
@@ -1827,6 +1832,9 @@ class Application(VuetifyTemplate, HubListener):
                 app=self, **optional_tray_kwargs
             )
             tray_item_label = tray.get('label')
+            # store a copy of the tray name in the instance so it can be accessed by the
+            # plugin itself
+            tray_item_instance._plugin_name = tray_item_label
 
             self.state.tray_items.append({
                 'name': name,
