@@ -1,6 +1,8 @@
+import astropy
 import numpy as np
 import pytest
 from astropy import units as u
+from astropy.utils.introspection import minversion
 from astropy.wcs import WCS
 from specutils import Spectrum1D
 from glue.core.roi import XRangeROI
@@ -9,6 +11,8 @@ from numpy.testing import assert_allclose, assert_array_equal
 
 from jdaviz.utils import PRIHDR_KEY
 
+ASTROPY_LT_5_3 = not minversion(astropy, "5.3.dev")
+
 
 @pytest.mark.filterwarnings('ignore')
 def test_fits_image_hdu_parse(image_cube_hdu_obj, cubeviz_helper):
@@ -42,30 +46,28 @@ def test_fits_image_hdu_with_microns(image_cube_hdu_obj_microns, cubeviz_helper)
         assert cubeviz_helper.app.data_collection[i].meta[PRIHDR_KEY]['BITPIX'] == 8
 
     flux_viewer = cubeviz_helper.app.get_viewer('flux-viewer')
-    flux_viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': 0, 'y': 0}})
-    assert flux_viewer.label_mouseover.pixel == 'x=00.0 y=00.0'
-    assert flux_viewer.label_mouseover.value == '+1.00000e+00 1e-17 erg / (Angstrom cm2 s)'
-
+    label_mouseover = cubeviz_helper.app.session.application._tools['g-coords-info']
+    label_mouseover._viewer_mouse_event(flux_viewer,
+                                        {'event': 'mousemove', 'domain': {'x': 0, 'y': 0}})
+    if ASTROPY_LT_5_3:
+        flux_unit_str = "erg / (Angstrom cm2 s)"
+    else:
+        flux_unit_str = "erg / (Angstrom s cm2)"
+    assert label_mouseover.as_text() == (f'Pixel x=00.0 y=00.0 Value +1.00000e+00 1e-17 {flux_unit_str}',  # noqa
+                                         'World 13h41m45.5759s +27d00m12.3044s (ICRS)',
+                                         '205.4398995981 27.0034178810 (deg)')  # noqa
     unc_viewer = cubeviz_helper.app.get_viewer('uncert-viewer')
-    unc_viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': -1, 'y': 0}})
-    assert unc_viewer.label_mouseover.pixel == 'x=-1.0 y=00.0'
-    assert unc_viewer.label_mouseover.value == ''  # Out of bounds
+    label_mouseover._viewer_mouse_event(unc_viewer,
+                                        {'event': 'mousemove', 'domain': {'x': -1, 'y': 0}})
+    assert label_mouseover.as_text() == ('Pixel x=-1.0 y=00.0',  # Out of bounds
+                                         'World 13h41m45.5856s +27d00m12.3044s (ICRS)',
+                                         '205.4399401278 27.0034178806 (deg)')
 
 
 def test_spectrum1d_with_fake_fixed_units(spectrum1d, cubeviz_helper):
-    header = {
-        'WCSAXES': 1,
-        'CRPIX1': 0.0,
-        'CDELT1': 1E-06,
-        'CUNIT1': 'm',
-        'CTYPE1': 'WAVE',
-        'CRVAL1': 0.0,
-        'RADESYS': 'ICRS'}
-    wcs = WCS(header)
     cubeviz_helper.app.add_data(spectrum1d, "test")
 
     dc = cubeviz_helper.app.data_collection
-    dc[0].meta["_orig_wcs"] = wcs
     dc[0].meta["_orig_spec"] = spectrum1d
 
     cubeviz_helper.app.add_data_to_viewer('spectrum-viewer', 'test')
@@ -100,18 +102,23 @@ def test_fits_image_hdu_parse_from_file(tmpdir, image_cube_hdu_obj, cubeviz_help
         assert cubeviz_helper.app.data_collection[i].meta[PRIHDR_KEY]['BITPIX'] == 8
 
     flux_viewer = cubeviz_helper.app.get_viewer(cubeviz_helper._default_flux_viewer_reference_name)
-    flux_viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': 0, 'y': 0}})
-    assert flux_viewer.label_mouseover.pixel == 'x=00.0 y=00.0'
-    assert flux_viewer.label_mouseover.value == '+1.00000e+00 1e-17 erg / (Angstrom cm2 s)'
-    assert flux_viewer.label_mouseover.world_ra_deg == '205.4433848390'
-    assert flux_viewer.label_mouseover.world_dec_deg == '26.9996149270'
+    label_mouseover = cubeviz_helper.app.session.application._tools['g-coords-info']
+    label_mouseover._viewer_mouse_event(flux_viewer,
+                                        {'event': 'mousemove', 'domain': {'x': 0, 'y': 0}})
+    if ASTROPY_LT_5_3:
+        flux_unit_str = "erg / (Angstrom cm2 s)"
+    else:
+        flux_unit_str = "erg / (Angstrom s cm2)"
+    assert label_mouseover.as_text() == (f'Pixel x=00.0 y=00.0 Value +1.00000e+00 1e-17 {flux_unit_str}',  # noqa
+                                         'World 13h41m46.5994s +26d59m58.6136s (ICRS)',
+                                         '205.4441642302 26.9996148973 (deg)')
 
     unc_viewer = cubeviz_helper.app.get_viewer(cubeviz_helper._default_uncert_viewer_reference_name)
-    unc_viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': -1, 'y': 0}})
-    assert unc_viewer.label_mouseover.pixel == 'x=-1.0 y=00.0'
-    assert unc_viewer.label_mouseover.value == ''  # Out of bounds
-    assert unc_viewer.label_mouseover.world_ra_deg == '205.4441642302'
-    assert unc_viewer.label_mouseover.world_dec_deg == '26.9996148973'
+    label_mouseover._viewer_mouse_event(unc_viewer,
+                                        {'event': 'mousemove', 'domain': {'x': -1, 'y': 0}})
+    assert label_mouseover.as_text() == ('Pixel x=-1.0 y=00.0',  # Out of bounds
+                                         'World 13h41m46.6368s +26d59m58.6136s (ICRS)',
+                                         '205.4443201084 26.9996148908 (deg)')
 
 
 @pytest.mark.filterwarnings('ignore')
@@ -128,17 +135,23 @@ def test_spectrum3d_parse(image_cube_hdu_obj, cubeviz_helper):
 
     # Same as flux viewer data in test_fits_image_hdu_parse_from_file
     flux_viewer = cubeviz_helper.app.get_viewer(cubeviz_helper._default_flux_viewer_reference_name)
-    flux_viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': 0, 'y': 0}})
-    assert flux_viewer.label_mouseover.pixel == 'x=00.0 y=00.0'
-    assert flux_viewer.label_mouseover.value == '+1.00000e+00 1e-17 erg / (Angstrom cm2 s)'
-    assert flux_viewer.label_mouseover.world_ra_deg == '205.4433848390'
-    assert flux_viewer.label_mouseover.world_dec_deg == '26.9996149270'
+    label_mouseover = cubeviz_helper.app.session.application._tools['g-coords-info']
+    label_mouseover._viewer_mouse_event(flux_viewer,
+                                        {'event': 'mousemove', 'domain': {'x': 0, 'y': 0}})
+    if ASTROPY_LT_5_3:
+        flux_unit_str = "erg / (Angstrom cm2 s)"
+    else:
+        flux_unit_str = "erg / (Angstrom s cm2)"
+    assert label_mouseover.as_text() == (f'Pixel x=00.0 y=00.0 Value +1.00000e+00 1e-17 {flux_unit_str}',  # noqa
+                                         'World 13h41m46.5994s +26d59m58.6136s (ICRS)',
+                                         '205.4441642302 26.9996148973 (deg)')
 
     # These viewers have no data.
 
     unc_viewer = cubeviz_helper.app.get_viewer(cubeviz_helper._default_uncert_viewer_reference_name)
-    unc_viewer.on_mouse_or_key_event({'event': 'mousemove', 'domain': {'x': -1, 'y': 0}})
-    assert unc_viewer.label_mouseover is None
+    label_mouseover._viewer_mouse_event(unc_viewer,
+                                        {'event': 'mousemove', 'domain': {'x': -1, 'y': 0}})
+    assert label_mouseover.as_text() == ('', '', '')
 
 
 def test_spectrum3d_no_wcs_parse(cubeviz_helper):
@@ -163,8 +176,8 @@ def test_spectrum1d_parse(spectrum1d, cubeviz_helper):
     assert cubeviz_helper.app.data_collection[0].meta['uncertainty_type'] == 'std'
 
     # Coordinate display is only for spatial image, which is missing here.
-    flux_viewer = cubeviz_helper.app.get_viewer(cubeviz_helper._default_flux_viewer_reference_name)
-    assert flux_viewer.label_mouseover is None
+    label_mouseover = cubeviz_helper.app.session.application._tools['g-coords-info']
+    assert label_mouseover.as_text() == ('', '', '')
 
 
 def test_numpy_cube(cubeviz_helper):
