@@ -16,7 +16,8 @@ from jdaviz.core.events import (AddDataMessage,
                                 AddLineListMessage,
                                 LineIdentifyMessage,
                                 SnackbarMessage,
-                                RedshiftMessage)
+                                RedshiftMessage,
+                                SpectralMarksChangedMessage)
 from jdaviz.core.linelists import load_preset_linelist, get_linelist_metadata
 from jdaviz.core.marks import SpectralLine
 from jdaviz.core.registries import tray_registry
@@ -117,6 +118,9 @@ class LineListTool(PluginTemplateMixin):
         self.hub.subscribe(self, LineIdentifyMessage,
                            handler=self._process_identify_change)
 
+        self.hub.subscribe(self, SpectralMarksChangedMessage,
+                           handler=lambda x: self.update_line_mark_dict())
+
         # if set to auto (default), update the slider range when zooming on the spectrum viewer
         self._viewer.state.add_callback("x_min",
                                         lambda x_min: self._on_spectrum_viewer_limits_changed())
@@ -162,9 +166,7 @@ class LineListTool(PluginTemplateMixin):
 
         label = msg.data.label
         try:
-            viewer_data = self.app.get_data_from_viewer(
-                self._default_spectrum_viewer_reference_name
-            ).get(label)
+            viewer_data = self.app._jdaviz_helper.get_data(data_label=label)
         except TypeError:
             warn_message = SnackbarMessage("Line list plugin could not retrieve data from viewer",
                                            sender=self, color="error")
