@@ -294,17 +294,7 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
 
     def _get_1d_spectrum(self):
         # retrieves the 1d spectrum (accounting for spatial subset for cubeviz, if necessary)
-        if self.config == 'cubeviz' and self.spatial_subset_selected != 'Entire Cube':
-            # then we're acting on the auto-collapsed data in the spectrum-viewer
-            # of a spatial subset.  In the future, we may want to expose on-the-fly
-            # collapse options... but right now these will follow the settings of the
-            # spectrum-viewer itself
-            return self.app.get_data_from_viewer(
-                                                 self._default_spectrum_viewer_reference_name,
-                                                 self.spatial_subset_selected
-                                                 )
-        else:
-            return self.dataset.selected_obj
+        return self.dataset.selected_spectrum_for_spatial_subset(self.spatial_subset_selected) # noqa
 
     @observe("dataset_selected", "spatial_subset_selected")
     def _dataset_selected_changed(self, event=None):
@@ -321,7 +311,7 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
             IPyWidget callback event object. In this case, represents the data
             label of the data collection object selected by the user.
         """
-        if not hasattr(self, 'dataset'):
+        if not hasattr(self, 'dataset') or self.app._jdaviz_helper is None or self.dataset_selected == '':  # noqa
             # during initial init, this can trigger before the component is initialized
             return
 
@@ -782,7 +772,10 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
             return
 
         # Get the primary data component
-        spec = data.get_object(cls=Spectrum1D, statistic=None)
+        if "_orig_spec" in data.meta:
+            spec = data.meta["_orig_spec"]
+        else:
+            spec = data.get_object(cls=Spectrum1D, statistic=None)
 
         snackbar_message = SnackbarMessage(
             "Fitting model to cube...",
@@ -825,8 +818,8 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
 
         # Create new glue data object
         output_cube = Data(label=label,
-                           coords=data.coords)
-        output_cube['flux'] = fitted_spectrum.flux.value
+                           coords=fitted_spectrum.wcs,
+                           flux=fitted_spectrum.flux.value)
         output_cube.get_component('flux').units = fitted_spectrum.flux.unit.to_string()
 
         if add_data:
