@@ -65,6 +65,8 @@ class TestCatalogs:
     # data used: information based on this image -
     # https://dr12.sdss.org/fields/runCamcolField?field=76&camcol=5&run=7674
     # the z-band FITS image was downloaded and used
+    # NOTE: We mark "slow" so it only runs on the dev job that is allowed to fail.
+    @pytest.mark.slow
     def test_plugin_image_with_result(self, imviz_helper, tmp_path):
         arr = np.ones((1489, 2048))
 
@@ -90,6 +92,10 @@ class TestCatalogs:
 
         catalogs_plugin = self.imviz.app.get_tray_item_from_name('imviz-catalogs')
         catalogs_plugin.plugin_opened = True
+        # This basically calls the following under the hood:
+        #   skycoord_center = SkyCoord(6.62754354, 1.54466139, unit="deg")
+        #   zoom_radius = r_max = 3 * u.arcmin
+        #   query_region_result = SDSS.query_region(skycoord_center, radius=zoom_radius, ...)
         catalogs_plugin.vue_do_search()
 
         # number of results should be > 500 or so
