@@ -1,6 +1,5 @@
 import numpy as np
 import pytest
-from asdf.fits_embed import AsdfInFits
 from astropy import units as u
 from astropy.io import fits
 from astropy.nddata import NDData, StdDevUncertainty
@@ -11,6 +10,7 @@ from gwcs import WCS as GWCS
 from numpy.testing import assert_allclose, assert_array_equal
 from regions import CirclePixelRegion, RectanglePixelRegion
 from skimage.io import imsave
+from stdatamodels import asdf_in_fits
 
 from jdaviz.configs.imviz.helper import split_filename_with_fits_ext
 from jdaviz.configs.imviz.plugins.parsers import (
@@ -221,14 +221,13 @@ class TestParseImage:
         with pytest.raises(ValueError, match='Do not manually overwrite data_label'):
             imviz_helper.load_data(flist, data_label='foo', show_in_viewer=False)
 
-    def test_parse_asdf_in_fits_4d(self, imviz_helper, tmpdir):
+    def test_parse_asdf_in_fits_4d(self, imviz_helper, tmp_path):
         hdulist = fits.HDUList([
             fits.PrimaryHDU(),
             fits.ImageHDU(np.zeros((1, 2, 5, 5)), name='SCI')])
         tree = {'data': {'data': hdulist['SCI'].data}}
-        filename = str(tmpdir.join('myasdf.fits'))
-        ff = AsdfInFits(hdulist, tree)
-        ff.write_to(filename, overwrite=True)
+        filename = str(tmp_path / 'myasdf.fits')
+        asdf_in_fits.write(filename, tree, hdulist=hdulist, overwrite=True)
 
         with pytest.raises(ValueError, match='Imviz cannot load this HDU'):
             parse_data(imviz_helper.app, filename)
@@ -360,16 +359,15 @@ class TestParseImage:
 
     @pytest.mark.remote_data
     def test_parse_jwst_niriss_grism(self, imviz_helper):
-        """No valid image GWCS for Imviz, will fall back to FITS loading without WCS."""
+        """No valid image GWCS for Imviz, will fall back to loading without WCS."""
         filename = download_file(self.jwst_asdf_url_2, cache=True)
 
         imviz_helper.load_data(filename, show_in_viewer=False)
         data = imviz_helper.app.data_collection[0]
-        comp = data.get_component('SCI,1')
-        assert data.label == 'contents[SCI,1]'  # download_file returns cache loc
+        comp = data.get_component('DATA')
+        assert data.label == 'contents[DATA]'  # download_file returns cache loc
         assert data.shape == (2048, 2048)
         assert data.coords is None
-        assert data.meta['RADESYS'] == 'ICRS'
         assert comp.units == 'DN/s'
         assert comp.data.shape == (2048, 2048)
 
@@ -409,7 +407,7 @@ class TestParseImage:
         assert_allclose(sky.dec.deg, 10.802045612042956, rtol=1e-3)
         data_unit = u.electron / u.s
         assert_quantity_allclose(tbl[0]['background'], 0.0014 * data_unit)
-        assert_quantity_allclose(tbl[0]['sum'], 126.219763 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['sum'], 126.63604794 * data_unit, rtol=1e-3)
         assert_quantity_allclose(tbl[0]['sum_aper_area'], 2583.959958 * (u.pix * u.pix), rtol=1e-3)
         assert_array_equal(tbl[0]['pixarea_tot'], None)
         assert_array_equal(tbl[0]['aperture_sum_counts'], None)
@@ -417,21 +415,21 @@ class TestParseImage:
         assert_array_equal(tbl[0]['counts_fac'], None)
         assert_array_equal(tbl[0]['aperture_sum_mag'], None)
         assert_array_equal(tbl[0]['flux_scaling'], None)
-        assert_quantity_allclose(tbl[0]['min'], -0.032984 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['max'], 4.905623 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['mean'], 0.048932 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['median'], 0.021932 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['mode'], -0.032068 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['std'], 0.152998 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['mad_std'], 0.023284 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['var'], 0.023408 * (data_unit * data_unit), rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['biweight_location'], 0.02106674 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['biweight_midvariance'], 0.00062667 * (data_unit * data_unit), rtol=1e-3)  # noqa
-        assert_quantity_allclose(tbl[0]['fwhm'], 25.311096 * u.pix, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['semimajor_sigma'], 13.018475 * u.pix, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['semiminor_sigma'], 7.847643 * u.pix, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['orientation'], 88.874367 * u.deg, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['eccentricity'], 0.797886, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['min'], -0.02858124 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['max'], 3.94278287 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['mean'], 0.04910025 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['median'], 0.02168917 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['mode'], -0.033133 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['std'], 0.144362 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['mad_std'], 0.0233135 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['var'], 0.02084 * (data_unit * data_unit), rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['biweight_location'], 0.02098 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['biweight_midvariance'], 0.00062222 * (data_unit * data_unit), rtol=1e-3)  # noqa
+        assert_quantity_allclose(tbl[0]['fwhm'], 25.22627 * u.pix, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['semimajor_sigma'], 12.9581226 * u.pix, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['semiminor_sigma'], 7.8490214 * u.pix, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['orientation'], 88.733606 * u.deg, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['eccentricity'], 0.795676, rtol=1e-3)
 
         # Request specific extension (name only), use given label
         imviz_helper.load_data(filename, ext='CTX', data_label='jclj01010_drz',
