@@ -1,7 +1,7 @@
 import warnings
 
 from astropy import units as u
-from astropy.utils.decorators import deprecated
+from glue.core.subset_group import GroupedSubset
 from specutils import SpectralRegion, Spectrum1D
 
 from jdaviz.core.helpers import ConfigHelper
@@ -67,20 +67,53 @@ class Specviz(ConfigHelper, LineListMixin):
                           show_in_viewer=show_in_viewer,
                           concat_by_file=concat_by_file)
 
-    def get_spectra(self, data_label=None, apply_slider_redshift="Warn"):
+    def get_spectra(self, data_label=None, subset_to_apply=None, apply_slider_redshift="Warn"):
         """Returns the current data loaded into the main viewer
 
         """
-        spectra = self.app.get_data_from_viewer(
-            self._default_spectrum_viewer_reference_name, data_label=data_label
-        )
+        spectra = {}
+        # Just to save line length
+        get_data_method = self.app._jdaviz_helper.get_data
+        viewer = self.app.get_viewer(self._default_spectrum_viewer_reference_name)
+        function_kwargs = {'function': getattr(viewer.state, "function")} if self.app.config == 'cubeviz' else {}  # noqa
+
+        if data_label is not None:
+            spectrum = get_data_method(data_label=data_label,
+                                       subset_to_apply=subset_to_apply,
+                                       cls=Spectrum1D)
+            spectra[data_label] = spectrum
+        else:
+            for layer_state in viewer.state.layers:
+                lyr = layer_state.layer
+                if subset_to_apply is not None:
+                    if lyr.label == subset_to_apply:
+                        spectrum = get_data_method(data_label=lyr.data.label,
+                                                   subset_to_apply=subset_to_apply,
+                                                   cls=Spectrum1D,
+                                                   **function_kwargs)
+                        spectra[lyr.data.label] = spectrum
+                    else:
+                        continue
+                else:
+                    if isinstance(lyr, GroupedSubset):
+                        spectrum = get_data_method(data_label=lyr.data.label,
+                                                   subset_to_apply=lyr.label,
+                                                   cls=Spectrum1D,
+                                                   **function_kwargs)
+                        spectra[f'{lyr.data.label} ({lyr.label})'] = spectrum
+                    else:
+                        spectrum = get_data_method(data_label=lyr.label,
+                                                   cls=Spectrum1D,
+                                                   **function_kwargs)
+                        spectra[lyr.label] = spectrum
+
         if not apply_slider_redshift:
+            if data_label is not None:
+                return spectra[data_label]
             return spectra
         else:
             output_spectra = {}
             # We need to create new Spectrum1D outputs with the redshifts set
-            if data_label is not None:
-                spectra = {data_label: spectra}
             for key in spectra.keys():
                 output_spectra[key] = _apply_redshift_to_spectra(spectra[key], self._redshift)
 
@@ -150,7 +183,7 @@ class Specviz(ConfigHelper, LineListMixin):
         ref_index = self.app.get_viewer(
             self._default_spectrum_viewer_reference_name
         ).state.reference_data.label
-        flux_axis = self.get_spectra(ref_index).flux
+        flux_axis = self.get_spectra(ref_index, apply_slider_redshift=False).flux
         self._set_scale(scale, flux_axis, y_min, y_max)
 
     def _set_scale(self, scale, axis, min_val=None, max_val=None):
@@ -240,8 +273,35 @@ class Specviz(ConfigHelper, LineListMixin):
             self._default_spectrum_viewer_reference_name
         ).figure.axes[axis].tick_format = fmt
 
+    def get_data(self, data_label=None, cls=None, subset_to_apply=None):
+        """
+        Returns data with name equal to data_label of type cls with subsets applied from
+        subset_to_apply.
 
-@deprecated('3.2', alternative='Specviz')
-class SpecViz(Specviz):
-    """This class is pending deprecation. Please use `Specviz` instead."""
-    pass
+        Parameters
+        ----------
+        data_label : str, optional
+            Provide a label to retrieve a specific data set from data_collection.
+        cls : `~specutils.Spectrum1D`, optional
+            The type that data will be returned as.
+        subset_to_apply : str, optional
+            Subset that is to be applied to data before it is returned.
+
+        Returns
+        -------
+        data : cls
+            Data is returned as type cls with subsets applied.
+
+        """
+        if self.app.config == 'cubeviz':
+            # then this is a specviz instance inside cubeviz and we want to default to the
+            # viewer's collapse function
+            default_sp_viewer = self.app.get_viewer(self._default_spectrum_viewer_reference_name)
+            function = getattr(default_sp_viewer.state, 'function', None)
+            if cls is None:
+                cls = Spectrum1D
+        else:
+            function = None
+
+        return self._get_data(data_label=data_label, cls=cls, subset_to_apply=subset_to_apply,
+                              function=function)
