@@ -26,7 +26,8 @@ from jdaviz.core.template_mixin import (PluginTemplateMixin,
                                         DatasetSelectMixin,
                                         SpectralSubsetSelectMixin,
                                         DatasetSpectralSubsetValidMixin,
-                                        SubsetSelect)
+                                        SubsetSelect,
+                                        SPATIAL_DEFAULT_TEXT)
 from jdaviz.core.user_api import PluginUserApi
 from jdaviz.core.tools import ICON_DIR
 
@@ -39,8 +40,6 @@ FUNCTIONS = {"Line Flux": analysis.line_flux,
              "Gaussian FWHM": analysis.gaussian_fwhm,
              "Centroid": analysis.centroid}
 
-SPATIAL_DEFAULT_TEXT = "Entire Cube"
-
 
 def _coerce_unit(quantity):
     """
@@ -173,9 +172,11 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelect
         if msg is None or msg.viewer_id != viewer_id or msg.data is None:
             return
 
-        viewer_data = self.app.get_data_from_viewer(
-            self._default_spectrum_viewer_reference_name
-        ).get(msg.data.label)
+        viewer = self.app.get_viewer(self._default_spectrum_viewer_reference_name)
+        get_data_kwargs = {'data_label': msg.data.label}
+        if self.config == 'cubeviz':
+            get_data_kwargs['function'] = getattr(viewer.state, 'function', None)
+        viewer_data = self.app._jdaviz_helper.get_data(**get_data_kwargs)
 
         # If no data is currently plotted, don't attempt to update
         if viewer_data is None:
@@ -300,7 +301,7 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelect
         Run the line analysis functions on the selected data/subset and
         display the results.
         """
-        if not hasattr(self, 'dataset'):
+        if not hasattr(self, 'dataset') or self.app._jdaviz_helper is None or self.dataset_selected == '':  # noqa
             # during initial init, this can trigger before the component is initialized
             return
 
@@ -314,17 +315,7 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelect
         # show spinner with overlay
         self.results_computing = True
 
-        if self.config == 'cubeviz' and self.spatial_subset_selected != SPATIAL_DEFAULT_TEXT:
-            # then we're acting on the auto-collapsed data in the spectrum-viewer
-            # of a spatial subset.  In the future, we may want to expose on-the-fly
-            # collapse options... but right now these will follow the settings of the
-            # spectrum-viewer itself
-            full_spectrum = self.app.get_data_from_viewer(
-                self._default_spectrum_viewer_reference_name,
-                self.spatial_subset_selected
-            )
-        else:
-            full_spectrum = self.dataset.selected_obj
+        full_spectrum = self.dataset.selected_spectrum_for_spatial_subset(self.spatial_subset_selected)  # noqa
 
         if (full_spectrum is None or self.width == "" or
                 (not self.plugin_opened and not kwargs.get('ignore_plugin_closed'))):
@@ -389,10 +380,12 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelect
                       'right': np.array([sr.upper.value, max(spectral_axis.value[continuum_mask])])}
 
         else:
-            continuum_mask = ~self.app.get_data_from_viewer(
-                self._default_spectrum_viewer_reference_name,
-                data_label=self.continuum_subset_selected
-            ).mask
+            # we'll access the mask of the continuum and then apply that to the spectrum.  For a
+            # spatially-collapsed spectrum in cubeviz, this will access the mask from the full
+            # cube, but still apply that to the spatially-collapsed spectrum.
+            continuum_mask = ~self._specviz_helper.get_data(
+                self.dataset.selected,
+                subset_to_apply=self.continuum_subset_selected).mask
             spectral_axis_nanmasked = spectral_axis.value.copy()
             spectral_axis_nanmasked[~continuum_mask] = np.nan
             if self.spectral_subset_selected == "Entire Spectrum":
@@ -435,6 +428,11 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelect
 
         temp_results = []
         spec_subtracted = spectrum - continuum
+
+        if spec_subtracted.mask is not None:
+            # temporary fix while mask may contain None:
+            spec_subtracted.mask = spec_subtracted.mask.astype(bool)
+
         for function in FUNCTIONS:
             # TODO: update specutils to allow ALL analysis to take regions and continuum so we
             # don't need these if statements
@@ -498,6 +496,9 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelect
                     continue
                 else:
                     spec_normalized = spectrum / continuum
+                    if spec_normalized.mask is not None:
+                        spec_normalized.mask = spec_normalized.mask.astype(bool)
+
                     temp_result = FUNCTIONS[function](spec_normalized)
             elif function == "Centroid":
                 # TODO: update specutils to be consistent with region vs regions and default to
