@@ -226,6 +226,18 @@ def mos_spectrum1d():
     return Spectrum1D(spectral_axis=spec_axis, flux=flux)
 
 
+@pytest.fixture
+def spectrum2d():
+    '''
+    A simple 2D Spectrum1D with a center "trace" array rising from 0 to 10
+    with two "zero array" buffers above and below
+    '''
+    data = np.zeros((5, 10))
+    data[3] = np.arange(10)
+
+    return Spectrum1D(flux=data*u.MJy, spectral_axis=data[3]*u.um)
+
+
 @pytest.fixture
 def mos_spectrum2d():
     '''
@@ -297,5 +309,6 @@ def pytest_configure(config):
     PYTEST_HEADER_MODULES['vispy'] = 'vispy'
     PYTEST_HEADER_MODULES['gwcs'] = 'gwcs'
     PYTEST_HEADER_MODULES['asdf'] = 'asdf'
+    PYTEST_HEADER_MODULES['stdatamodels'] = 'stdatamodels'
 
     TESTED_VERSIONS['jdaviz'] = __version__
