@@ -5,7 +5,8 @@ __all__ = ['NewViewerMessage', 'ViewerAddedMessage', 'ViewerRemovedMessage', 'Lo
            'AddLineListMessage', 'RowLockMessage',
            'SliceSelectSliceMessage',
            'SliceToolStateMessage',
-           'TableClickMessage', 'LinkUpdatedMessage', 'ExitBatchLoadMessage']
+           'TableClickMessage', 'LinkUpdatedMessage', 'ExitBatchLoadMessage',
+           'MarkersChangedMessage']
 
 
 class NewViewerMessage(Message):
@@ -304,3 +305,14 @@ class ExitBatchLoadMessage(Message):
     '''Message generated when exiting the outermost batch_load context manager'''
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+
+
+class MarkersChangedMessage(Message):
+    '''Message generated when markers are added/removed from an image viewer'''
+    def __init__(self, has_markers, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._has_markers = has_markers
+
+    @property
+    def has_markers(self):
+        return self._has_markers
