@@ -43,6 +43,9 @@ class FreezableProfileViewerState(ProfileViewerState, FreezableState):
                     x_min = min(x_min, np.nanmin(x))
                     x_max = max(x_max, np.nanmax(x))
 
+        if not np.all(np.isfinite([x_min, x_max])):
+            return
+
         with delay_callback(self, 'x_min', 'x_max'):
             self.x_min = x_min
             self.x_max = x_max
@@ -55,6 +58,9 @@ class FreezableBqplotImageViewerState(BqplotImageViewerState, FreezableState):
         super().__init__(*args, **kwargs)
 
     def reset_limits(self, *event):
+        if self.reference_data is None:  # Nothing to do
+            return
+
         wcs_success = False
         if self.linked_by_wcs and self.reference_data.coords is not None:
             x_min, x_max = np.inf, -np.inf
