@@ -1,3 +1,7 @@
+from astropy.coordinates.sky_coordinate import SkyCoord
+from astropy.table import QTable
+from astropy.table.row import Row as QTableRow
+import astropy.units as u
 import numpy as np
 
 from functools import cached_property
@@ -25,14 +29,19 @@ from jdaviz.core.user_api import UserApiWrapper, PluginUserApi
 
 __all__ = ['show_widget', 'TemplateMixin', 'PluginTemplateMixin',
            'BasePluginComponent', 'SelectPluginComponent',
+           'PluginSubcomponent',
            'SubsetSelect', 'SpatialSubsetSelectMixin', 'SpectralSubsetSelectMixin',
            'DatasetSpectralSubsetValidMixin',
            'ViewerSelect', 'ViewerSelectMixin',
            'LayerSelect', 'LayerSelectMixin',
            'DatasetSelect', 'DatasetSelectMixin',
+           'Table', 'TableMixin',
            'AutoTextField', 'AutoTextFieldMixin',
            'AddResults', 'AddResultsMixin',
-           'PlotOptionsSyncState']
+           'PlotOptionsSyncState',
+           'SPATIAL_DEFAULT_TEXT']
+
+SPATIAL_DEFAULT_TEXT = "Entire Cube"
 
 
 def show_widget(widget, loc, title):  # pragma: no cover
@@ -80,6 +89,18 @@ def show_widget(widget, loc, title):  # pragma: no cover
         raise ValueError(f"Unrecognized display location: {loc}")
 
 
+def _subset_type(subset):
+    while hasattr(subset.subset_state, 'state1'):
+        # this assumes no mixing between spatial and spectral subsets and just
+        # taking the first component (down the hierarchical tree) to determine the type
+        subset = subset.subset_state.state1
+
+    if isinstance(subset.subset_state, RoiSubsetState):
+        return 'spatial'
+    else:
+        return 'spectral'
+
+
 class TemplateMixin(VuetifyTemplate, HubListener):
     config = Unicode("").tag(sync=True)
     vdocs = Unicode("").tag(sync=True)
@@ -110,6 +131,9 @@ class TemplateMixin(VuetifyTemplate, HubListener):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.popout_button = PopoutButton(self, window_features='popup,width=400,height=600')
+        self._viewer_callbacks = {}
+        self.hub.subscribe(self, ViewerRemovedMessage,
+                           handler=lambda msg: self._remove_viewer_callbacks(msg.viewer_id))
 
     @property
     def app(self):
@@ -132,6 +156,37 @@ class TemplateMixin(VuetifyTemplate, HubListener):
     def data_collection(self):
         return self._app.session.data_collection
 
+    @property
+    def _specviz_helper(self):
+        # for helpers that have a .specviz, return that, otherwise the original helper
+        helper = self.app._jdaviz_helper
+        return getattr(helper, 'specviz', helper)
+
+    def _viewer_callback(self, viewer, plugin_method):
+        """
+        Cached access to callbacks to a plugin method to attach to a viewer.
+        To define a callback:
+        def _on_callback(self, viewer, data):
+        To add callback:
+        viewer.add_event_calback(self._viewer_callback(viewer, self._on_callback),
+                                 events=['keydown'])
+        To remove callback:
+        viewer.remove_event_callback(self._viewer_callback(viewer, self._on_callback))
+        """
+        def plugin_viewer_callback(viewer, plugin_method):
+            return lambda data: plugin_method(viewer, data)
+
+        key = f'{viewer.reference_id}:{plugin_method.__name__}'
+        if key not in self._viewer_callbacks.keys():
+            self._viewer_callbacks[key] = plugin_viewer_callback(viewer, plugin_method)
+        return self._viewer_callbacks.get(key)
+
+    def _remove_viewer_callbacks(self, viewer_id):
+        # removes the cache of a callback when a viewer is removed (the viewer object is already
+        # assumed destroyed, so we do not need to remove the event callback itself from the viewer)
+        self._viewer_callbacks = {k: v for k, v in self._viewer_callbacks.items()
+                                  if k.split(':')[0] != viewer_id}
+
 
 class PluginTemplateMixin(TemplateMixin):
     """
@@ -141,6 +196,7 @@ class PluginTemplateMixin(TemplateMixin):
     plugin_opened = Bool(False).tag(sync=True)
 
     def __init__(self, **kwargs):
+        self._viewer_callbacks = {}
         super().__init__(**kwargs)
         self.app.state.add_callback('tray_items_open', self._mxn_update_plugin_opened)
         self.app.state.add_callback('drawer', self._mxn_update_plugin_opened)
@@ -151,6 +207,28 @@ class PluginTemplateMixin(TemplateMixin):
         # can even be dependent on config, etc.
         return PluginUserApi(self, expose=[])
 
+    def _viewer_callback(self, viewer, plugin_method):
+        """
+        Cached access to callbacks to a plugin method to attach to a viewer.
+
+        To define a callback:
+        def _on_callback(self, viewer, data):
+
+        To add callback:
+        viewer.add_event_calback(self._viewer_callback(viewer, self._on_callback),
+                                 events=['keydown'])
+
+        To remove callback:
+        viewer.remove_event_callback(self._viewer_callback(viewer, self._on_callback))
+        """
+        def plugin_viewer_callback(viewer, plugin_method):
+            return lambda data: plugin_method(viewer, data)
+
+        key = f'{viewer.reference_id}:{plugin_method.__name__}'
+        if key not in self._viewer_callbacks.keys():
+            self._viewer_callbacks[key] = plugin_viewer_callback(viewer, plugin_method)
+        return self._viewer_callbacks.get(key)
+
     def _mxn_update_plugin_opened(self, new_value):
         app_state = self.app.state
         tray_names_open = [app_state.tray_items[i]['name'] for i in app_state.tray_items_open]
@@ -427,6 +505,19 @@ class SelectPluginComponent(BasePluginComponent, HasTraits):
         self.selected = []
         return self.selected
 
+    def select_next(self):
+        """
+        Select next entry in the choices, wrapping when reaching the end.  Raises an error if
+        :meth:`is_multiselect`
+        """
+        if self.is_multiselect:
+            raise ValueError("currently in multiselect mode")
+
+        cycle = self.choices
+        curr_ind = cycle.index(self.selected)
+        self.selected = cycle[(curr_ind + 1) % len(cycle)]
+        return self.selected
+
     @property
     def default_text(self):
         return self._default_text
@@ -863,13 +954,6 @@ class SubsetSelect(SelectPluginComponent):
         for lyr in self.app.data_collection.subset_groups:
             self._update_subset(lyr)
 
-    @staticmethod
-    def _subset_type(subset):
-        if isinstance(subset.subset_state, RoiSubsetState):
-            return 'spatial'
-        else:
-            return 'spectral'
-
     def _selected_changed(self, event):
         super()._selected_changed(event)
         self._update_has_subregions()
@@ -880,7 +964,7 @@ class SubsetSelect(SelectPluginComponent):
             for layer in viewer.layers:
                 if layer.layer.label == subset.label:
                     color = layer.state.color
-                    subset_type = self._subset_type(subset)
+                    subset_type = _subset_type(subset)
                     return {"label": subset.label, "color": color, "type": subset_type}
         return {"label": subset.label, "color": False, "type": False}
 
@@ -892,7 +976,7 @@ class SubsetSelect(SelectPluginComponent):
             self._apply_default_selection()
 
     def _update_subset(self, subset, attribute=None):
-        if self._allowed_type is not None and self._subset_type(subset) != self._allowed_type:
+        if self._allowed_type is not None and _subset_type(subset) != self._allowed_type:
             return
 
         if subset.label not in self.labels:
@@ -947,30 +1031,18 @@ class SubsetSelect(SelectPluginComponent):
 
     @property
     def selected_subset_mask(self):
-        if self._allowed_type == 'spatial':
-            viewer_ref = getattr(self.plugin,
-                                 '_default_flux_viewer_reference_name',
-                                 self.viewers[0].reference_id)
-        elif self._allowed_type == 'spectral':
+        get_data_kwargs = {'data_label': self.plugin.dataset.selected,
+                           'subset_to_apply': self.selected}
+
+        if self.app.config == 'cubeviz' and self._allowed_type == 'spectral':
             viewer_ref = getattr(self.plugin,
                                  '_default_spectrum_viewer_reference_name',
                                  self.viewers[0].reference_id)
+            get_data_kwargs['function'] = self.app.get_viewer(viewer_ref).state.function
 
-        subset = self.app.get_data_from_viewer(
-            viewer_ref, data_label=self.selected
-        )
+        subset = self.app._jdaviz_helper.get_data(**get_data_kwargs)
 
-        if hasattr(subset, 'mask'):
-            # the mask attr is available for spectral subsets:
-            subset_mask = subset.mask
-        else:
-            # `subset` is a GroupedSubset.
-            # We take the logical-not of the mask here, since the glue subset masks
-            # are True in selected regions and False outside. This is the opposite of
-            # the numpy/astropy/specutils convention where True is masked-out.
-            subset_mask = ~subset.to_mask()
-
-        return subset_mask
+        return subset.mask
 
     def selected_min_max(self, spectrum1d):
         if self.selected_obj is None:
@@ -1357,6 +1429,27 @@ class DatasetSelect(SelectPluginComponent):
         # initialize items from original viewers
         self._on_data_changed()
 
+    def _cubeviz_include_spatial_subsets(self):
+        """
+        Call this method to prepend spatial subsets to the list of datasets (and listen for newly
+        created spatial subsets).  For a single viewer, consider using LayerSelect instead.
+        """
+        if self.app.config != 'cubeviz':
+            return
+
+        # add additional callback for subsets
+        # We have to use SubsetUpdateMessage instead of SubsetCreateMessage to ensure it has already
+        # been added to data_collection.subset_groups.  To avoid extra calls to _on_data_changed
+        # for changes in style, etc, we'll try to filter out extra messages in advance.
+        def _subset_update(msg):
+            if msg.attribute == 'subset_state':
+                if _subset_type(msg.subset) == 'spatial':
+                    self._on_data_changed()
+
+        self.hub.subscribe(self, SubsetUpdateMessage,
+                           handler=_subset_update)
+        self._include_spatial_subsets = True
+
     @property
     def default_data_cls(self):
         if self.app.config == 'imviz':
@@ -1383,21 +1476,19 @@ class DatasetSelect(SelectPluginComponent):
         if self.selected not in self.labels:
             # _apply_default_selection will override shortly anyways
             return None
-        for viewer_ref in self.viewer_refs:
-            if viewer_ref is None:
-                # image viewers might not have a reference, but get_data_from_viewer
-                # does not take id
-                continue
-            match = self.app.get_data_from_viewer(viewer_ref, data_label=self.selected)
-            if match is not None:
-                if hasattr(match, 'get_object'):
-                    # cube viewers return the data collection instance from get_data_from_viewer
-                    return match.get_object(cls=self.default_data_cls)
-                return match
+        match = self.app._jdaviz_helper.get_data(data_label=self.selected)
+        if match is not None:
+            return match
         # handle the case of empty Application with no viewer, we'll just pull directly
         # from the data collection
         return self.get_object(cls=self.default_data_cls)
 
+    def selected_spectrum_for_spatial_subset(self, spatial_subset=SPATIAL_DEFAULT_TEXT):
+        if spatial_subset == SPATIAL_DEFAULT_TEXT:
+            spatial_subset = None
+        return self.plugin._specviz_helper.get_data(data_label=self.selected,
+                                                    subset_to_apply=spatial_subset)
+
     def _is_valid_item(self, data):
         def not_from_plugin(data):
             return data.meta.get('Plugin', None) is None
@@ -1436,6 +1527,9 @@ class DatasetSelect(SelectPluginComponent):
             return not is_trace(data)
 
         def is_image(data):
+            return len(data.shape) == 2
+
+        def is_cube(data):
             return len(data.shape) == 3
 
         return super()._is_valid_item(data, locals())
@@ -1453,6 +1547,10 @@ class DatasetSelect(SelectPluginComponent):
         manual_items = [{'label': label} for label in self.manual_options]
         self.items = manual_items + [_dc_to_dict(data) for data in self.app.data_collection
                                      if self._is_valid_item(data)]
+        if getattr(self, '_include_spatial_subsets', False):
+            # allow for spatial subsets to be listed
+            self.items = self.items + [_dc_to_dict(subset) for subset in self.app.data_collection.subset_groups  # noqa
+                                       if _subset_type(subset) == 'spatial']
         self._apply_default_selection()
         # future improvement: only clear cache if the selected data entry was changed?
         self._clear_cache(*self._cached_properties)
@@ -2108,3 +2206,212 @@ class PlotOptionsSyncState(BasePluginComponent):
         self._on_value_changed({'new': self.value})
         self.sync = {**self.sync,
                      'mixed': False}
+
+
+# SUBCOMPONENTS (will not have top-level plugin traitlets but can be rendered on their own in
+# popout windows or in the app)
+
+class PluginSubcomponent(VuetifyTemplate):
+    popout_button = Any().tag(sync=True, **widget_serialization)
+
+    def __init__(self, plugin, component_type='table', *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._plugin = plugin
+        self._component_type = component_type
+        self.popout_button = PopoutButton(self, window_features='popup,width=800,height=300')
+
+    @property
+    def display_name(self):
+        return f'{self._plugin._plugin_name}: {self._component_type}'
+
+    def vue_popout(self, data=None):
+        self.show(loc='popout')
+
+    def show(self, loc="inline", title=None):  # pragma: no cover
+        """Display the component UI.
+
+        Parameters
+        ----------
+        loc : str
+            The display location determines where to present the viz app.
+            Supported locations:
+
+            "inline": Display the component inline in a notebook.
+
+            "app": Display below the viewers in the main app.
+
+            "sidecar": Display the component in a separate JupyterLab window from the
+            notebook, the location of which is decided by the 'anchor.' right is the default
+
+                Other anchors:
+
+                * ``sidecar:right`` (The default, opens a tab to the right of display)
+                * ``sidecar:tab-before`` (Full-width tab before the current notebook)
+                * ``sidecar:tab-after`` (Full-width tab after the current notebook)
+                * ``sidecar:split-right`` (Split-tab in the same window right of the notebook)
+                * ``sidecar:split-left`` (Split-tab in the same window left of the notebook)
+                * ``sidecar:split-top`` (Split-tab in the same window above the notebook)
+                * ``sidecar:split-bottom`` (Split-tab in the same window below the notebook)
+
+                See `jupyterlab-sidecar <https://github.com/jupyter-widgets/jupyterlab-sidecar>`_
+                for the most up-to-date options.
+
+            "popout": Display the component in a detached display. By default, a new
+            window will open. Browser popup permissions required.
+
+                Other anchors:
+
+                * ``popout:window`` (The default, opens Jdaviz in a new, detached popout)
+                * ``popout:tab`` (Opens Jdaviz in a new, detached tab in your browser)
+
+        title : str, optional
+            The title of the sidecar tab.  Defaults to the name of the component.
+
+            NOTE: Only applicable to a "sidecar" display.
+
+        Notes
+        -----
+        If "sidecar" is requested in the "classic" Jupyter notebook, the component will appear
+        inline, as only JupyterLab has a mechanism to have multiple tabs.
+        """
+        title = title if title is not None else self.display_name
+        show_widget(self, loc=loc, title=title)
+
+
+class Table(PluginSubcomponent):
+    """
+    Table subcomponent.  For most cases where a plugin only requires a single table, use the mixin
+    instead.
+
+    To use in a plugin, define ``plugin.table = Table(plugin)``, create a ``table_widget`` Unicode
+    traitlet, and set ``plugin.table_widget = 'IPY_MODEL_'+self.table.model_id``.
+
+    To render in the plugin's vue file::
+
+      <jupyter-widget :widget="table_widget"></jupyter-widget>
+
+    """
+    template_file = __file__, "../components/plugin_table.vue"
+
+    headers_visible = List([]).tag(sync=True)  # list of strings
+    headers_avail = List([]).tag(sync=True)   # list of strings
+    items = List().tag(sync=True)  # list of dictionaries, pass single dict to add_row
+
+    def __init__(self, plugin, *args, **kwargs):
+        self._qtable = None
+        super().__init__(plugin, 'Table', *args, **kwargs)
+
+    def add_item(self, item):
+        """
+        Add an item/row to the table.
+
+        Parameters
+        ----------
+        item : QTable, QTableRow, or dictionary of row-name, value pairs
+        """
+        def json_safe(column, item):
+            def float_precision(column, item):
+                if column in ('slice', 'index'):
+                    # stored in astropy table as a float so we can also store nans,
+                    # but should display in the UI without any decimals
+                    return int(item)
+                elif column in ('pixel'):
+                    return f"{item:0.03f}"
+                else:
+                    return f"{item:0.05f}"
+
+            if isinstance(item, SkyCoord):
+                return item.to_string('hmsdms', precision=4)
+            if isinstance(item, u.Quantity) and not np.isnan(item):
+                return (float_precision(column, item.value) * item.unit).to_string()
+
+            if hasattr(item, 'to_string'):
+                return item.to_string()
+            if isinstance(item, float) and np.isnan(item):
+                return ''
+            if isinstance(item, tuple) and np.all([np.isnan(i) for i in item]):
+                return ''
+
+            if isinstance(item, float):
+                return float_precision(column, item)
+            elif isinstance(item, (list, tuple)):
+                return [float_precision(column, i) if isinstance(i, float) else i for i in item]
+
+            return item
+
+        if isinstance(item, QTable):
+            for row in item:
+                self.add_item(row)
+            return
+        if isinstance(item, QTableRow):
+            # Row does not have .items() implemented
+            item = {k: v for k, v in zip(item.keys(), item.values())}
+
+        # save original sent values to the cached QTable object
+        if self._qtable is None:
+            self._qtable = QTable([item])
+        else:
+            # NOTE: this does not support adding columns that did not exist in the first
+            # call to add_row since the last call to clear_table
+            self._qtable.add_row(item)
+
+        # clean data to show in the UI
+        self.items = self.items + [{k: json_safe(k, v) for k, v in item.items()}]
+
+    def clear_table(self):
+        """
+        Clear all entries/markers from the current table.
+        """
+        self.items = []
+        self._qtable = None
+
+    def vue_clear_table(self, data=None):
+        # if the plugin (or via the TableMixin) has its own clear_table implementation,
+        # call that, otherwise call the one defined here
+        getattr(self._plugin, 'clear_table', self.clear_table)()
+
+    def export_table(self):
+        """
+        Export the QTable representation of the table.
+        """
+        # TODO: default to only showing selected columns?
+        return self._qtable
+
+
+class TableMixin(VuetifyTemplate, HubListener):
+    """
+    Table subcomponent mixin.
+
+    In addition to ``table``, this provides the following methods at the plugin-level:
+
+    * :meth:`clear_table`
+    * :meth:`export_table`
+
+    To render in the plugin's vue file::
+
+      <jupyter-widget :widget="table_widget"></jupyter-widget>
+
+    """
+    table_widget = Unicode().tag(sync=True)
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.table = Table(self)
+        self.table_widget = 'IPY_MODEL_'+self.table.model_id
+
+    def clear_table(self):
+        """
+        Clear all entries/markers from the current table.
+        """
+        self.table.clear_table()
+
+    def vue_clear_table(self, data=None):
+        # call clear_table directly in case the class overloads that method
+        # (to also clear markers, etc)
+        self.clear_table()
+
+    def export_table(self):
+        """
+        Export the QTable representation of the table.
+        """
+        return self.table.export_table()
